==> yt_3.2.3.orig.tar.gz: yt-3.2.3/yt/fields/field_aliases.py <==
"""
Some old field names.



"""

#-----------------------------------------------------------------------------
# Copyright (c) 2013, yt Development Team.
#
# Distributed under the terms of the Modified BSD License.
#
# The full license is in the file COPYING.txt, distributed with this software.
#-----------------------------------------------------------------------------


_field_name_aliases = [
    ("GridLevel",                        "grid_level"),
    ("GridIndices",                      "grid_indices"),
    ("OnesOverDx",                       "ones_over_dx"),
    ("Ones",                             "ones"),
    #("CellsPerBin",                      "cells_per_bin"),
    ("SoundSpeed",                       "sound_speed"),
    ("RadialMachNumber",                 "radial_mach_number"),
    ("MachNumber",                       "mach_number"),
    ("CourantTimeStep",                  "courant_time_step"),
    #("ParticleVelocityMagnitude",        "particle_velocity_magnitude"),
    ("VelocityMagnitude",                "velocity_magnitude"),
    ("TangentialOverVelocityMagnitude",  "tangential_over_velocity_magnitude"),
    ("Pressure",                         "pressure"),
    ("Entropy",                          "entropy"),
    ("sph_r",                            "spherical_r"),
    ("sph_theta",                        "spherical_theta"),
    ("sph_phi",                          "spherical_phi"),
    ("cyl_R",                            "cylindrical_r"),
    ("cyl_z",                            "cylindrical_z"),
    ("cyl_theta",                        "cylindrical_theta"),
    ("cyl_RadialVelocity",               "cylindrical_radial_velocity"),
    ("cyl_RadialVelocityABS",            "cylindrical_radial_velocity_absolute"),
    ("cyl_TangentialVelocity",           "cylindrical_tangential_velocity"),
    ("cyl_TangentialVelocityABS",        "cylindrical_tangential_velocity_absolute"),
    ("DynamicalTime",                    "dynamical_time"),
    ("JeansMassMsun",                    "jeans_mass"),
    ("CellMass",                         "cell_mass"),
    ("TotalMass",                        "total_mass"),
    ("StarMassMsun",                     "star_mass"),
    ("Matter_Density",                   "matter_density"),
    ("ComovingDensity",                  "comoving_density"),
    ("Overdensity",                      "overdensity"),
    ("DensityPerturbation",              "density_perturbation"),
    ("Baryon_Overdensity",               "baryon_overdensity"),
    ("WeakLensingConvergence",           "weak_lensing_convergence"),
    ("CellVolume",                       "cell_volume"),
    ("ChandraEmissivity",                "chandra_emissivity"),
    ("XRayEmissivity",                   "xray_emissivity"),
    ("SZKinetic",                        "sz_kinetic"),
    ("SZY",                              "szy"),
    ("AveragedDensity",                  "averaged_density"),
    ("DivV",                             "div_v"),
    ("AbsDivV",                          "div_v_absolute"),
    ("Contours",                         "contours"),
    ("tempContours",                     "temp_contours"),
    ("SpecificAngularMomentumX",         "specific_angular_momentum_x"),
    ("SpecificAngularMomentumY",         "specific_angular_momentum_y"),
    ("SpecificAngularMomentumZ",         "specific_angular_momentum_z"),
    ("AngularMomentumX",                 "angular_momentum_x"),
    ("AngularMomentumY",                 "angular_momentum_y"),
    ("AngularMomentumZ",                 "angular_momentum_z"),
    #("ParticleSpecificAngularMomentumX", "particle_specific_angular_momentum_x"),
    #("ParticleSpecificAngularMomentumY", "particle_specific_angular_momentum_y"),
    #("ParticleSpecificAngularMomentumZ", "particle_specific_angular_momentum_z"),
    #("ParticleAngularMomentumX",         "particle_angular_momentum_x"),
    #("ParticleAngularMomentumY",         "particle_angular_momentum_y"),
    #("ParticleAngularMomentumZ",         "particle_angular_momentum_z"),
    #("ParticleRadius",                   "particle_radius"),
    ("Radius",                           "radius"),
    ("RadialVelocity",                   "radial_velocity"),
    ("RadialVelocityABS",                "radial_velocity_absolute"),
    ("TangentialVelocity",               "tangential_velocity"),
    ("CuttingPlaneVelocityX",            "cutting_plane_velocity_x"),
    ("CuttingPlaneVelocityY",            "cutting_plane_velocity_y"),
    ("CuttingPlaneBX",                   "cutting_plane_bx"),
    ("CuttingPlaneBy",                   "cutting_plane_by"),
    ("MeanMolecularWeight",              "mean_molecular_weight"),
    ("particle_density",                 "particle_density"),
    ("ThermalEnergy",                    "thermal_energy"),
    ("TotalEnergy",                      "total_energy"),
    ("MagneticEnergy",                   "magnetic_energy"),
    ("GasEnergy",                        "thermal_energy"),
    ("Gas_Energy",                       "thermal_energy"),
    ("BMagnitude",                       "b_magnitude"),
    ("PlasmaBeta",                       "plasma_beta"),
    ("MagneticPressure",                 "magnetic_pressure"),
    ("BPoloidal",                        "b_poloidal"),
    ("BToroidal",                        "b_toroidal"),
    ("BRadial",                          "b_radial"),
    ("VorticitySquared",                 "vorticity_squared"),
    ("gradPressureX",                    "grad_pressure_x"),
    ("gradPressureY",                    "grad_pressure_y"),
    ("gradPressureZ",                    "grad_pressure_z"),
    ("gradPressureMagnitude",            "grad_pressure_magnitude"),
    ("gradDensityX",                     "grad_density_x"),
    ("gradDensityY",                     "grad_density_y"),
    ("gradDensityZ",                     "grad_density_z"),
    ("gradDensityMagnitude",             "grad_density_magnitude"),
    ("BaroclinicVorticityX",             "baroclinic_vorticity_x"),
    ("BaroclinicVorticityY",             "baroclinic_vorticity_y"),
    ("BaroclinicVorticityZ",             "baroclinic_vorticity_z"),
    ("BaroclinicVorticityMagnitude",     "baroclinic_vorticity_magnitude"),
    ("VorticityX",                       "vorticity_x"),
    ("VorticityY",                       "vorticity_y"),
    ("VorticityZ",                       "vorticity_z"),
    ("VorticityMagnitude",               "vorticity_magnitude"),
    ("VorticityStretchingX",             "vorticity_stretching_x"),
    ("VorticityStretchingY",             "vorticity_stretching_y"),
    ("VorticityStretchingZ",             "vorticity_stretching_z"),
    ("VorticityStretchingMagnitude",     "vorticity_stretching_magnitude"),
    ("VorticityGrowthX",                 "vorticity_growth_x"),
    ("VorticityGrowthY",                 "vorticity_growth_y"),
    ("VorticityGrowthZ",                 "vorticity_growth_z"),
    ("VorticityGrowthMagnitude",         "vorticity_growth_magnitude"),
    ("VorticityGrowthMagnitudeABS",      "vorticity_growth_magnitude_absolute"),
    ("VorticityGrowthTimescale",         "vorticity_growth_timescale"),
    ("VorticityRadPressureX",            "vorticity_radiation_pressure_x"),
    ("VorticityRadPressureY",            "vorticity_radiation_pressure_y"),
    ("VorticityRadPressureZ",            "vorticity_radiation_pressure_z"),
    ("VorticityRadPressureMagnitude",    "vorticity_radiation_pressure_magnitude"),
    ("VorticityRPGrowthX",               "vorticity_radiation_pressure_growth_x"),
    ("VorticityRPGrowthY",               "vorticity_radiation_pressure_growth_y"),
    ("VorticityRPGrowthZ",               "vorticity_radiation_pressure_growth_z"),
    ("VorticityRPGrowthMagnitude",       "vorticity_radiation_pressure_growth_magnitude"),
    ("VorticityRPGrowthTimescale",       "vorticity_radiation_pressure_growth_timescale"),
    ("DiskAngle",                        "theta"),
    ("Height",                           "height"),
]

_field_units_aliases = [
    ("cyl_RCode",                             "code_length"),
    ("HeightAU",                              "au"),
    ("cyl_RadialVelocityKMS",                 "km/s"),
    ("cyl_RadialVelocityKMSABS",              "km/s"),
    ("cyl_TangentialVelocityKMS",             "km/s"),
    ("cyl_TangentialVelocityKMSABS",          "km/s"),
    ("CellMassMsun",                          "msun"),
    ("CellMassCode",                          "code_mass"),
    ("TotalMassMsun",                         "msun"),
    ("CellVolumeCode",                        "code_length"),
    ("CellVolumeMpc",                         "Mpc**3"),
    ("ParticleSpecificAngularMomentumXKMSMPC","km/s/Mpc"),
    ("ParticleSpecificAngularMomentumYKMSMPC","km/s/Mpc"),
    ("ParticleSpecificAngularMomentumZKMSMPC","km/s/Mpc"),
    ("RadiusMpc",                             "Mpc"),
    ("ParticleRadiusMpc",                     "Mpc"),
    ("ParticleRadiuskpc",                     "kpc"),
    ("Radiuskpc",                             "kpc"),
    ("ParticleRadiuskpch",                    "kpc"),
    ("Radiuskpch",                            "kpc"),
    ("ParticleRadiuspc",                      "pc"),
    ("Radiuspc",                              "pc"),
    ("ParticleRadiusAU",                      "au"),
    ("RadiusAU",                              "au"),
    ("ParticleRadiusCode",                    "code_length"),
    ("RadiusCode",                            "code_length"),
    ("RadialVelocityKMS",                     "km/s"),
    ("RadialVelocityKMSABS",                  "km/s"),
    ("JeansMassMsun",                         "msun"),
]

==> yt_3.4.0.orig.tar.gz: yt-3.4.0/yt/fields/field_aliases.py <==
"""
Some old field names.



"""

#-----------------------------------------------------------------------------
# Copyright (c) 2013, yt Development Team.
#
# Distributed under the terms of the Modified BSD License.
#
# The full license is in the file COPYING.txt, distributed with this software.
#-----------------------------------------------------------------------------


_field_name_aliases = [
    ("GridLevel",                        "grid_level"),
    ("GridIndices",                      "grid_indices"),
    ("OnesOverDx",                       "ones_over_dx"),
    ("Ones",                             "ones"),
    #("CellsPerBin",                      "cells_per_bin"),
    ("SoundSpeed",                       "sound_speed"),
    ("RadialMachNumber",                 "radial_mach_number"),
    ("MachNumber",                       "mach_number"),
    ("CourantTimeStep",                  "courant_time_step"),
    #("ParticleVelocityMagnitude",        "particle_velocity_magnitude"),
    ("VelocityMagnitude",                "velocity_magnitude"),
    ("TangentialOverVelocityMagnitude",  "tangential_over_velocity_magnitude"),
    ("Pressure",                         "pressure"),
    ("Entropy",                          "entropy"),
    ("sph_r",                            "spherical_r"),
    ("sph_theta",                        "spherical_theta"),
    ("sph_phi",                          "spherical_phi"),
    ("cyl_R",                            "cylindrical_r"),
    ("cyl_z",                            "cylindrical_z"),
    ("cyl_theta",                        "cylindrical_theta"),
    ("cyl_RadialVelocity",               "cylindrical_radial_velocity"),
    ("cyl_RadialVelocityABS",            "cylindrical_radial_velocity_absolute"),
    ("cyl_TangentialVelocity",           "cylindrical_tangential_velocity"),
    ("cyl_TangentialVelocityABS",        "cylindrical_tangential_velocity_absolute"),
    ("DynamicalTime",                    "dynamical_time"),
    ("JeansMassMsun",                    "jeans_mass"),
    ("CellMass",                         "cell_mass"),
    ("TotalMass",                        "total_mass"),
    ("StarMassMsun",                     "star_mass"),
    ("Matter_Density",                   "matter_density"),
    ("ComovingDensity",                  "comoving_density"),
    ("Overdensity",                      "overdensity"),
    ("DensityPerturbation",              "density_perturbation"),
    ("Baryon_Overdensity",               "baryon_overdensity"),
    ("WeakLensingConvergence",           "weak_lensing_convergence"),
    ("CellVolume",                       "cell_volume"),
    ("ChandraEmissivity",                "chandra_emissivity"),
    ("XRayEmissivity",                   "xray_emissivity"),
    ("SZKinetic",                        "sz_kinetic"),
    ("SZY",                              "szy"),
    ("AveragedDensity",                  "averaged_density"),
    ("DivV",                             "div_v"),
    ("AbsDivV",                          "div_v_absolute"),
    ("Contours",                         "contours"),
    ("tempContours",                     "temp_contours"),
    ("SpecificAngularMomentumX",         "specific_angular_momentum_x"),
    ("SpecificAngularMomentumY",         "specific_angular_momentum_y"),
    ("SpecificAngularMomentumZ",         "specific_angular_momentum_z"),
    ("AngularMomentumX",                 "angular_momentum_x"),
    ("AngularMomentumY",                 "angular_momentum_y"),
    ("AngularMomentumZ",                 "angular_momentum_z"),
    #("ParticleSpecificAngularMomentumX", "particle_specific_angular_momentum_x"),
    #("ParticleSpecificAngularMomentumY", "particle_specific_angular_momentum_y"),
    #("ParticleSpecificAngularMomentumZ", "particle_specific_angular_momentum_z"),
    #("ParticleAngularMomentumX",         "particle_angular_momentum_x"),
    #("ParticleAngularMomentumY",         "particle_angular_momentum_y"),
    #("ParticleAngularMomentumZ",         "particle_angular_momentum_z"),
    #("ParticleRadius",                   "particle_radius"),
    ("Radius",                           "radius"),
    ("RadialVelocity",                   "radial_velocity"),
    ("RadialVelocityABS",                "radial_velocity_absolute"),
    ("TangentialVelocity",               "tangential_velocity"),
    ("CuttingPlaneVelocityX",            "cutting_plane_velocity_x"),
    ("CuttingPlaneVelocityY",            "cutting_plane_velocity_y"),
    ("CuttingPlaneBX",                   "cutting_plane_magnetic_field_x"),
    ("CuttingPlaneBy",                   "cutting_plane_magnetic_field_y"),
    ("MeanMolecularWeight",              "mean_molecular_weight"),
    ("particle_density",                 "particle_density"),
    ("ThermalEnergy",                    "thermal_energy"),
    ("TotalEnergy",                      "total_energy"),
    ("MagneticEnergy",                   "magnetic_energy"),
    ("GasEnergy",                        "thermal_energy"),
    ("Gas_Energy",                       "thermal_energy"),
    ("BMagnitude",                       "b_magnitude"),
    ("PlasmaBeta",                       "plasma_beta"),
    ("MagneticPressure",                 "magnetic_pressure"),
    ("BPoloidal",                        "b_poloidal"),
    ("BToroidal",                        "b_toroidal"),
    ("BRadial",                          "b_radial"),
    ("VorticitySquared",                 "vorticity_squared"),
    ("gradPressureX",                    "grad_pressure_x"),
    ("gradPressureY",                    "grad_pressure_y"),
    ("gradPressureZ",                    "grad_pressure_z"),
    ("gradPressureMagnitude",            "grad_pressure_magnitude"),
    ("gradDensityX",                     "grad_density_x"),
    ("gradDensityY",                     "grad_density_y"),
    ("gradDensityZ",                     "grad_density_z"),
    ("gradDensityMagnitude",             "grad_density_magnitude"),
    ("BaroclinicVorticityX",             "baroclinic_vorticity_x"),
    ("BaroclinicVorticityY",             "baroclinic_vorticity_y"),
    ("BaroclinicVorticityZ",             "baroclinic_vorticity_z"),
    ("BaroclinicVorticityMagnitude",     "baroclinic_vorticity_magnitude"),
    ("VorticityX",                       "vorticity_x"),
    ("VorticityY",                       "vorticity_y"),
    ("VorticityZ",                       "vorticity_z"),
    ("VorticityMagnitude",               "vorticity_magnitude"),
    ("VorticityStretchingX",             "vorticity_stretching_x"),
    ("VorticityStretchingY",             "vorticity_stretching_y"),
    ("VorticityStretchingZ",             "vorticity_stretching_z"),
    ("VorticityStretchingMagnitude",     "vorticity_stretching_magnitude"),
    ("VorticityGrowthX",                 "vorticity_growth_x"),
    ("VorticityGrowthY",                 "vorticity_growth_y"),
    ("VorticityGrowthZ",                 "vorticity_growth_z"),
    ("VorticityGrowthMagnitude",         "vorticity_growth_magnitude"),
    ("VorticityGrowthMagnitudeABS",      "vorticity_growth_magnitude_absolute"),
    ("VorticityGrowthTimescale",         "vorticity_growth_timescale"),
    ("VorticityRadPressureX",            "vorticity_radiation_pressure_x"),
    ("VorticityRadPressureY",            "vorticity_radiation_pressure_y"),
    ("VorticityRadPressureZ",            "vorticity_radiation_pressure_z"),
    ("VorticityRadPressureMagnitude",    "vorticity_radiation_pressure_magnitude"),
    ("VorticityRPGrowthX",               "vorticity_radiation_pressure_growth_x"),
    ("VorticityRPGrowthY",               "vorticity_radiation_pressure_growth_y"),
    ("VorticityRPGrowthZ",               "vorticity_radiation_pressure_growth_z"),
    ("VorticityRPGrowthMagnitude",       "vorticity_radiation_pressure_growth_magnitude"),
    ("VorticityRPGrowthTimescale",       "vorticity_radiation_pressure_growth_timescale"),
    ("DiskAngle",                        "theta"),
    ("Height",                           "height"),
]

_field_units_aliases = [
    ("cyl_RCode",                             "code_length"),
    ("HeightAU",                              "au"),
    ("cyl_RadialVelocityKMS",                 "km/s"),
    ("cyl_RadialVelocityKMSABS",              "km/s"),
    ("cyl_TangentialVelocityKMS",             "km/s"),
    ("cyl_TangentialVelocityKMSABS",          "km/s"),
    ("CellMassMsun",                          "msun"),
    ("CellMassCode",                          "code_mass"),
    ("TotalMassMsun",                         "msun"),
    ("CellVolumeCode",                        "code_length"),
    ("CellVolumeMpc",                         "Mpc**3"),
    ("ParticleSpecificAngularMomentumXKMSMPC","km/s/Mpc"),
    ("ParticleSpecificAngularMomentumYKMSMPC","km/s/Mpc"),
    ("ParticleSpecificAngularMomentumZKMSMPC","km/s/Mpc"),
    ("RadiusMpc",                             "Mpc"),
    ("ParticleRadiusMpc",                     "Mpc"),
    ("ParticleRadiuskpc",                     "kpc"),
    ("Radiuskpc",                             "kpc"),
    ("ParticleRadiuskpch",                    "kpc"),
    ("Radiuskpch",                            "kpc"),
    ("ParticleRadiuspc",                      "pc"),
    ("Radiuspc",                              "pc"),
    ("ParticleRadiusAU",                      "au"),
    ("RadiusAU",                              "au"),
    ("ParticleRadiusCode",                    "code_length"),
    ("RadiusCode",                            "code_length"),
    ("RadialVelocityKMS",                     "km/s"),
    ("RadialVelocityKMSABS",                  "km/s"),
    ("JeansMassMsun",                         "msun"),
]
